@@ -14,7 +14,7 @@ Created on 29 Mar 2020
 """
 # pylint: disable=invalid-name
 
-from math import log, sin, sqrt, pi
+from math import log, sin, sqrt, pi, floor, ceil
 
 from PIL import Image
 from numba import jit, prange
@@ -27,10 +27,12 @@ from colormaps.pastels256_colormap import pastels256
 from colormaps.tropical_colormap import tropical16, tropical256
 from colormaps.twilight256_colormap import twilight256
 
+PERIODCHECK = True  # Turn periodicity check optimisation on/off
 MANDELBROT = 0
 JULIA = 1
+STANDARD = 0
+BURNINGSHIP = 1
 TRICORN = 2
-BURNINGSHIP = 3
 
 THEMES = [
     "Default",
@@ -61,6 +63,7 @@ THEMES = [
 def plot(
     imagemap,
     settype,
+    setvar,
     width,
     height,
     zoom,
@@ -85,6 +88,7 @@ def plot(
             # Invoke core algorithm to calculate escape scalars
             i, z = fractal(
                 settype,
+                setvar,
                 width,
                 height,
                 x_axis,
@@ -100,12 +104,13 @@ def plot(
             )
 
             # Look up color for these escape scalars and set pixel in imagemap
-            imagemap[y_axis, x_axis] = get_color(i, z, maxiter, theme, shift)
+            imagemap[y_axis, x_axis] = get_color(i, z, radius, maxiter, theme, shift)
 
 
 @jit(nopython=True, cache=True)
 def fractal(
     settype,
+    setvar,
     width,
     height,
     x_axis,
@@ -127,6 +132,8 @@ def fractal(
     """
 
     zx_coord, zy_coord = ptoc(width, height, x_axis, y_axis, zxoff, zyoff, zoom)
+    lastz = complex(0, 0)
+    per = 0
 
     z = complex(zx_coord, zy_coord)
     if settype == JULIA:  # Julia or variant
@@ -134,18 +141,30 @@ def fractal(
     else:  # Mandelbrot or variant
         c = z
 
-    for i in prange(maxiter):  # pylint: disable=not-an-iterable
+    for i in prange(maxiter + 1):  # pylint: disable=not-an-iterable
         # Iterate till the point c is outside the escape radius.
-        if settype == BURNINGSHIP:
+        if setvar == BURNINGSHIP:
             z = complex(abs(z.real), -abs(z.imag))
-        if settype == TRICORN:
+        if setvar == TRICORN:
             z = z.conjugate()
         z = z ** exponent + c
 
+        # Optimisation - periodicity check speeds
+        # up processing of points within set
+        if PERIODCHECK:
+            if z == lastz:
+                i = maxiter
+                break
+            per += 1
+            if per > 20:
+                per = 0
+                lastz = z
+        # ... end of optimisation
+
         if abs(z) > radius ** 2:
             break
 
-    return i, z
+    return i, abs(z)
 
 
 @jit(nopython=True, cache=True)
@@ -173,7 +192,7 @@ def ctop(width, height, zx_coord, zy_coord, zxoff, zyoff, zoom):
 
 
 @jit(nopython=True, cache=True)
-def get_color(i, z, maxiter, theme, shift):
+def get_color(i, z, radius, maxiter, theme, shift):
     """
     Uses escape scalars i, z from the fractal algorithm to drive a variety
     of color rendering algorithms or 'themes'.
@@ -183,9 +202,7 @@ def get_color(i, z, maxiter, theme, shift):
     Numba-recognised data types and suitably decorated library functions).
     """
 
-    if (
-        i == maxiter - 1 and theme != "BasicGrayscale"
-    ):  # Inside Mandelbrot set, so black
+    if i == maxiter and theme != "BasicGrayscale":  # Inside Mandelbrot set, so black
         return 0, 0, 0
 
     if theme == "Default":
@@ -200,7 +217,7 @@ def get_color(i, z, maxiter, theme, shift):
             s = 1.0
         r, g, b = hsv_to_rgb(h, s, 1.0)
     elif theme == "BasicGrayscale":
-        if i == maxiter - 1:
+        if i == maxiter:
             return 255, 255, 255
         r = 256 * i / maxiter
         b = g = r
@@ -213,76 +230,99 @@ def get_color(i, z, maxiter, theme, shift):
         g = bands[i % 4]
         b = bands[(i // 16) % 4]
     elif theme == "NormalizedHue":
-        h = ((normalize(i, z) / maxiter) + (shift / 100)) % 1
+        h = ((normalize(i, z, radius) / maxiter) + (shift / 100)) % 1
         r, g, b = hsv_to_rgb(h, 0.75, 1)
     elif theme == "SqrtHue":
-        h = ((normalize(i, z) / sqrt(maxiter)) + (shift / 100)) % 1
+        h = ((normalize(i, z, radius) / sqrt(maxiter)) + (shift / 100)) % 1
         r, g, b = hsv_to_rgb(h, 0.75, 1)
     elif theme == "LogHue":
-        h = ((normalize(i, z) / log(maxiter)) + (shift / 100)) % 1
+        h = ((normalize(i, z, radius) / log(maxiter)) + (shift / 100)) % 1
         r, g, b = hsv_to_rgb(h, 0.75, 1)
     elif theme == "SinHue":
-        h = normalize(i, z) * sin(((shift + 1) / 100) * pi / 2)
+        h = normalize(i, z, radius) * sin(((shift + 1) / 100) * pi / 2)
         r, g, b = hsv_to_rgb(h, 0.75, 1)
     elif theme == "SinSqrtHue":
         steps = 1 + shift / 100
-        h = 1 - (sin((normalize(i, z) / sqrt(maxiter) * steps) + 1) / 2)
+        h = 1 - (sin((normalize(i, z, radius) / sqrt(maxiter) * steps) + 1) / 2)
         r, g, b = hsv_to_rgb(h, 0.75, 1)
     else:  # Indexed colormap arrays
-        r, g, b = sel_colormap(i, z, shift, theme)
+        r, g, b = sel_colormap(i, z, radius, shift, theme)
     return r, g, b
 
 
 @jit(nopython=True, cache=True)
-def sel_colormap(i, z, shift, theme):
+def sel_colormap(i, z, radius, shift, theme):
     """
     Select from indexed colormap theme
     """
 
     if theme == "Colorcet_CET_CBC1":
-        r, g, b = get_colormap(i, z, shift, cet_CBC1)
+        r, g, b = get_colormap(i, z, radius, shift, cet_CBC1)
     if theme == "Colorcet_CET_CBTC1":
-        r, g, b = get_colormap(i, z, shift, cet_CBTC1)
+        r, g, b = get_colormap(i, z, radius, shift, cet_CBTC1)
     if theme == "Colorcet_CET_C1":
-        r, g, b = get_colormap(i, z, shift, cet_C1)
+        r, g, b = get_colormap(i, z, radius, shift, cet_C1)
     if theme == "Colorcet_CET_C4s":
-        r, g, b = get_colormap(i, z, shift, cet_C4s)
+        r, g, b = get_colormap(i, z, radius, shift, cet_C4s)
     if theme == "BlueBrown16":
-        r, g, b = get_colormap(i, z, shift, BlueBrown16)
+        r, g, b = get_colormap(i, z, radius, shift, BlueBrown16)
     if theme == "Tropical16":
-        r, g, b = get_colormap(i, z, shift, tropical16)
+        r, g, b = get_colormap(i, z, radius, shift, tropical16)
     if theme == "Tropical256":
-        r, g, b = get_colormap(i, z, shift, tropical256)
+        r, g, b = get_colormap(i, z, radius, shift, tropical256)
     if theme == "Pastels256":
-        r, g, b = get_colormap(i, z, shift, pastels256)
+        r, g, b = get_colormap(i, z, radius, shift, pastels256)
     if theme == "Metallic256":
-        r, g, b = get_colormap(i, z, shift, metallic256)
+        r, g, b = get_colormap(i, z, radius, shift, metallic256)
     if theme == "Twilight256":
-        r, g, b = get_colormap(i, z, shift, twilight256)
+        r, g, b = get_colormap(i, z, radius, shift, twilight256)
     if theme == "Landscape256":
-        r, g, b = get_colormap(i, z, shift, landscape256)
+        r, g, b = get_colormap(i, z, radius, shift, landscape256)
 
     return r, g, b
 
 
 @jit(nopython=True, cache=True)
-def get_colormap(i, z, shift, colmap):
+def get_colormap(i, za, radius, shift, colmap):
     """
     Get pixel color from colormap
     """
 
-    col = int((normalize(i, z)) + (shift * len(colmap) / 100)) % len(colmap)
-    return colmap[col]
+    # col = int((normalize(i, z, radius)) + (shift * len(colmap) / 100)) % len(colmap)
+    # return colmap[col]
+
+    ni = normalize(i, za, radius)  # normalised iteration count
+    sh = ceil(shift * len(colmap) / 100)  # palette shift
+    col1 = colmap[(floor(ni) + sh) % len(colmap)]
+    col2 = colmap[(floor(ni) + sh + 1) % len(colmap)]
+    return interpolate(col1, col2, ni)
 
 
 @jit(nopython=True, cache=True)
-def normalize(i, z):
+def normalize(i, za, radius):
     """
     Normalize iteration count from escape scalars.
     (NB: should ideally be (log(log2(abs(z))) but Numba doesn't currently handle log2)
     """
 
-    return i + 1 - (log(log(abs(z))) / log(2.0))
+    # return i + 1 - (log(log(abs(z))) / log(2.0))
+
+    lzn = log(za ** 2) / 2
+    nu = log(lzn / log(radius)) / log(2)
+    return i + 1 - nu
+
+
+@jit(nopython=True, cache=True)
+def interpolate(col1, col2, ni):
+    """
+    Linear interpolation between two colours.
+    """
+
+    f = ni % 1  # fractional part of ni
+    r = (col2[0] - col1[0]) * f + col1[0]
+    g = (col2[1] - col1[1]) * f + col1[1]
+    b = (col2[2] - col1[2]) * f + col1[2]
+    return [r, g, b]
 
 
 @jit(nopython=True, cache=True)
@@ -291,14 +331,14 @@ def hsv_to_rgb(h, s, v):
     Convert HSV values (in range 0-1) to RGB (in range 0-255).
     """
 
+    v = int(v * 255)
     if s == 0.0:
-        v = int(v * 255)
         return v, v, v
     i = int(h * 6.0)
     f = (h * 6.0) - i
-    p = v * (1.0 - s)
-    q = v * (1.0 - s * f)
-    t = v * (1.0 - s * (1.0 - f))
+    p = int(v * (1.0 - s))
+    q = int(v * (1.0 - s * f))
+    t = int(v * (1.0 - s * (1.0 - f)))
     i %= 6
     if i == 0:
         r, g, b = v, t, p
@@ -313,7 +353,6 @@ def hsv_to_rgb(h, s, v):
     if i == 5:
         r, g, b = v, p, q
 
-    r, g, b = int(r * 255), int(g * 255), int(b * 255)
     return r, g, b
 
 
@@ -334,6 +373,7 @@ class Mandelbrot:
     def plot_image(
         self,
         settype,
+        setvar,
         width,
         height,
         zoom,
@@ -357,6 +397,7 @@ class Mandelbrot:
         plot(
             imagemap,
             settype,
+            setvar,
             width,
             height,
             zoom,
