@@ -19,6 +19,7 @@ import sys
 from time import time
 
 from pymandel.mandelbrot import Mandelbrot, MANDELBROT, JULIA
+from pymandel.strings import MODULENAME
 
 sys.path.append("pymandel")
 sys.path.append("colormaps")
@@ -33,6 +34,7 @@ def help_text():
         "Mandelbrot Generator command line utility\n (c) SEMU Consulting - BSD 3 License\n\n",
         "The following keyword parameters can be passed (default):\n\n",
         "settype - 'Mandelbrot' or 'Julia' ('Mandelbrot')\n",
+        "setvar - 'Standard', 'BurningShip' or 'Tricorn' ('Standard')\n",
         "width - the width of the image(s) in pixels (1920)\n",
         "height - the height of the image(s) in pixels (1080)\n",
         "zoom - the initial zoom level (0.75)\n",
@@ -51,7 +53,7 @@ def help_text():
         "filepath - the path for saved files ($cwd)\n",
         "filename - the name prefix for saved files ('frame')\n\n",
         "import - the full path to a previously saved metadata file ('')\n\n",
-        "e.g. python mandelcli.py width=1920 height=1080 import='test.json'",
+        "e.g. pymandelcli width=1920 height=1080 import='test.json'",
     )
 
 
@@ -66,21 +68,18 @@ class BatchMandelbrot:
         """
 
         print("Parameters passed: ", kwargs)
-        self._importfile = kwargs.get("import", "")
-        if self._importfile != "":
-            if not self.import_metadata(self._importfile):
-                return
         self._setmode = kwargs.get("settype", "Mandelbrot")
         if self._setmode == "Julia":
             self._settype = JULIA
         else:
             self._settype = MANDELBROT
+        self._setvar = kwargs.get("setvar", "Standard")
         self._width = int(kwargs.get("width", 1920))
         self._height = int(kwargs.get("height", 1080))
         self._radius = int(kwargs.get("escradius", 2))
         self._exponent = int(kwargs.get("exponent", 2))
         self._zx_off = float(kwargs.get("zxoffset", -0.5))
-        self._zy_off = float(kwargs.get("cyoffset", 0.0))
+        self._zy_off = float(kwargs.get("zyoffset", 0.0))
         self._cx_off = float(kwargs.get("cxoffset", 0.0))
         self._cy_off = float(kwargs.get("cyoffset", 0.0))
         self._filepath = kwargs.get("filepath", ".")
@@ -103,6 +102,11 @@ class BatchMandelbrot:
             kwargs.get("maxiter", abs(1000 * log(1 / sqrt(self._zoom))))
         )
 
+        self._importfile = kwargs.get("import", "")
+        if self._importfile != "":
+            if not self.import_metadata(self._importfile):
+                return
+
         start = time()
 
         self.animate()
@@ -132,6 +136,7 @@ class BatchMandelbrot:
 
             self.mandelbrot.plot_image(
                 self._settype,
+                self._setvar,
                 self._width,
                 self._height,
                 self._zoom,
@@ -173,22 +178,25 @@ class BatchMandelbrot:
 
         # Parse file
         settings = loads(jsondata)
-        self._settype = settings["mandelbrot"]["settype"]
-        self._zoom = settings["mandelbrot"]["zoom"]
-        self._radius = settings["mandelbrot"]["escradius"]
-        self._exponent = settings["mandelbrot"]["exponent"]
-        self._maxiter = settings["mandelbrot"]["maxiter"]
-        self._zx_off = settings["mandelbrot"]["zxoffset"]
-        self._zy_off = settings["mandelbrot"]["zyoffset"]
-        self._cx_off = settings["mandelbrot"]["cxoffset"]
-        self._cy_off = settings["mandelbrot"]["cyoffset"]
-        self._theme = settings["mandelbrot"]["theme"]
-        self._shift = settings["mandelbrot"]["shift"]
+        self._settype = settings[MODULENAME]["settype"]
+        self._setvar = settings[MODULENAME]["setvar"]
+        self._zoom = float(settings[MODULENAME]["zoom"])
+        self._radius = float(settings[MODULENAME]["escradius"])
+        self._exponent = int(settings[MODULENAME]["exponent"])
+        self._maxiter = int(settings[MODULENAME]["maxiter"])
+        self._zx_off = float(settings[MODULENAME]["zxoffset"])
+        self._zy_off = float(settings[MODULENAME]["zyoffset"])
+        self._cx_off = float(settings[MODULENAME]["cxoffset"])
+        self._cy_off = float(settings[MODULENAME]["cyoffset"])
+        self._theme = settings[MODULENAME]["theme"]
+        self._shift = int(settings[MODULENAME]["shift"])
+        self._frames = int(settings[MODULENAME]["frames"])
 
         return True
 
 
-if __name__ == "__main__":
+def main(args=None):
+    """Entry point for CLI."""
 
     if len(sys.argv) > 1:
         if sys.argv[1] in {"-h", "--h", "help", "-help", "--help", "-H"}:
@@ -196,3 +204,7 @@ if __name__ == "__main__":
             sys.exit()
 
     BatchMandelbrot(**dict(arg.split("=") for arg in sys.argv[1:]))
+
+
+if __name__ == "__main__":
+    sys.exit(main())
